#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'taskcolorsbase.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TASKCOLORSBASE_H
#define UI_TASKCOLORSBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_TaskColorsBase
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QLabel *numberLabel;
    KColorButton *kcfg_numberColor;
    QLabel *operationLabel;
    KColorButton *kcfg_operationColor;
    QLabel *fractionBarLabel;
    KColorButton *kcfg_fractionBarColor;

    void setupUi(QWidget *TaskColorsBase)
    {
        if (TaskColorsBase->objectName().isEmpty())
            TaskColorsBase->setObjectName(QStringLiteral("TaskColorsBase"));
        TaskColorsBase->resize(231, 139);
        gridLayout = new QGridLayout(TaskColorsBase);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        groupBox = new QGroupBox(TaskColorsBase);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout1 = new QGridLayout(groupBox);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        numberLabel = new QLabel(groupBox);
        numberLabel->setObjectName(QStringLiteral("numberLabel"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(numberLabel->sizePolicy().hasHeightForWidth());
        numberLabel->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(numberLabel, 0, 0, 1, 1);

        kcfg_numberColor = new KColorButton(groupBox);
        kcfg_numberColor->setObjectName(QStringLiteral("kcfg_numberColor"));

        gridLayout1->addWidget(kcfg_numberColor, 0, 2, 1, 1);

        operationLabel = new QLabel(groupBox);
        operationLabel->setObjectName(QStringLiteral("operationLabel"));
        sizePolicy.setHeightForWidth(operationLabel->sizePolicy().hasHeightForWidth());
        operationLabel->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(operationLabel, 1, 0, 1, 1);

        kcfg_operationColor = new KColorButton(groupBox);
        kcfg_operationColor->setObjectName(QStringLiteral("kcfg_operationColor"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_operationColor->sizePolicy().hasHeightForWidth());
        kcfg_operationColor->setSizePolicy(sizePolicy1);

        gridLayout1->addWidget(kcfg_operationColor, 1, 2, 1, 1);

        fractionBarLabel = new QLabel(groupBox);
        fractionBarLabel->setObjectName(QStringLiteral("fractionBarLabel"));
        sizePolicy.setHeightForWidth(fractionBarLabel->sizePolicy().hasHeightForWidth());
        fractionBarLabel->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(fractionBarLabel, 2, 0, 1, 1);

        kcfg_fractionBarColor = new KColorButton(groupBox);
        kcfg_fractionBarColor->setObjectName(QStringLiteral("kcfg_fractionBarColor"));

        gridLayout1->addWidget(kcfg_fractionBarColor, 2, 2, 1, 1);


        gridLayout->addWidget(groupBox, 0, 0, 1, 1);

#ifndef UI_QT_NO_SHORTCUT
        numberLabel->setBuddy(kcfg_numberColor);
        operationLabel->setBuddy(kcfg_operationColor);
        fractionBarLabel->setBuddy(kcfg_fractionBarColor);
#endif // QT_NO_SHORTCUT

        retranslateUi(TaskColorsBase);

        QMetaObject::connectSlotsByName(TaskColorsBase);
    } // setupUi

    void retranslateUi(QWidget *TaskColorsBase)
    {
        groupBox->setTitle(tr2i18n("Colors", 0));
        numberLabel->setText(tr2i18n("&Number:", 0));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_numberColor->setToolTip(tr2i18n("Change the color of the numbers", 0));
#endif // QT_NO_TOOLTIP
        kcfg_numberColor->setText(QString());
        operationLabel->setText(tr2i18n("&Operation sign:", 0));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_operationColor->setToolTip(tr2i18n("Change the color of the operation signs", 0));
#endif // QT_NO_TOOLTIP
        kcfg_operationColor->setText(QString());
        fractionBarLabel->setText(tr2i18n("&Fraction bar:", 0));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_fractionBarColor->setToolTip(tr2i18n("Change the color of the fraction bar", 0));
#endif // QT_NO_TOOLTIP
        kcfg_fractionBarColor->setText(QString());
        Q_UNUSED(TaskColorsBase);
    } // retranslateUi

};

namespace Ui {
    class TaskColorsBase: public Ui_TaskColorsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TASKCOLORSBASE_H

