/****************************************************************************
** Meta object code from reading C++ file 'MainQtWidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kbruch-17.04.3/src/MainQtWidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainQtWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_MainQtWidget_t {
    QByteArrayData data[23];
    char stringdata0[389];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainQtWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainQtWidget_t qt_meta_stringdata_MainQtWidget = {
    {
QT_MOC_LITERAL(0, 0, 12), // "MainQtWidget"
QT_MOC_LITERAL(1, 13, 15), // "OperationsCheck"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 16), // "SelectArithmetic"
QT_MOC_LITERAL(4, 47, 16), // "SelectComparison"
QT_MOC_LITERAL(5, 64, 16), // "SelectConversion"
QT_MOC_LITERAL(6, 81, 18), // "SelectMixedNumbers"
QT_MOC_LITERAL(7, 100, 19), // "SelectFactorization"
QT_MOC_LITERAL(8, 120, 16), // "SelectPercentage"
QT_MOC_LITERAL(9, 137, 20), // "ReducedFormCheckSlot"
QT_MOC_LITERAL(10, 158, 22), // "QuestionMixedCheckSlot"
QT_MOC_LITERAL(11, 181, 20), // "AnswerMixedCheckSlot"
QT_MOC_LITERAL(12, 202, 17), // "AdditionCheckSlot"
QT_MOC_LITERAL(13, 220, 20), // "SubtractionCheckSlot"
QT_MOC_LITERAL(14, 241, 23), // "MultiplicationCheckSlot"
QT_MOC_LITERAL(15, 265, 17), // "DivisionCheckSlot"
QT_MOC_LITERAL(16, 283, 16), // "NrOfTermsBoxSlot"
QT_MOC_LITERAL(17, 300, 25), // "MaxMainDenominatorBoxSlot"
QT_MOC_LITERAL(18, 326, 7), // "newTask"
QT_MOC_LITERAL(19, 334, 9), // "slotPrefs"
QT_MOC_LITERAL(20, 344, 17), // "slotApplySettings"
QT_MOC_LITERAL(21, 362, 19), // "slotAboutToShowPage"
QT_MOC_LITERAL(22, 382, 6) // "goBack"

    },
    "MainQtWidget\0OperationsCheck\0\0"
    "SelectArithmetic\0SelectComparison\0"
    "SelectConversion\0SelectMixedNumbers\0"
    "SelectFactorization\0SelectPercentage\0"
    "ReducedFormCheckSlot\0QuestionMixedCheckSlot\0"
    "AnswerMixedCheckSlot\0AdditionCheckSlot\0"
    "SubtractionCheckSlot\0MultiplicationCheckSlot\0"
    "DivisionCheckSlot\0NrOfTermsBoxSlot\0"
    "MaxMainDenominatorBoxSlot\0newTask\0"
    "slotPrefs\0slotApplySettings\0"
    "slotAboutToShowPage\0goBack"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainQtWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x08 /* Private */,
       3,    0,  120,    2, 0x08 /* Private */,
       4,    0,  121,    2, 0x08 /* Private */,
       5,    0,  122,    2, 0x08 /* Private */,
       6,    0,  123,    2, 0x08 /* Private */,
       7,    0,  124,    2, 0x08 /* Private */,
       8,    0,  125,    2, 0x08 /* Private */,
       9,    0,  126,    2, 0x08 /* Private */,
      10,    0,  127,    2, 0x08 /* Private */,
      11,    0,  128,    2, 0x08 /* Private */,
      12,    0,  129,    2, 0x08 /* Private */,
      13,    0,  130,    2, 0x08 /* Private */,
      14,    0,  131,    2, 0x08 /* Private */,
      15,    0,  132,    2, 0x08 /* Private */,
      16,    0,  133,    2, 0x08 /* Private */,
      17,    0,  134,    2, 0x08 /* Private */,
      18,    0,  135,    2, 0x08 /* Private */,
      19,    0,  136,    2, 0x08 /* Private */,
      20,    0,  137,    2, 0x08 /* Private */,
      21,    0,  138,    2, 0x08 /* Private */,
      22,    0,  139,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MainQtWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainQtWidget *_t = static_cast<MainQtWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->OperationsCheck();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 1: _t->SelectArithmetic(); break;
        case 2: _t->SelectComparison(); break;
        case 3: _t->SelectConversion(); break;
        case 4: _t->SelectMixedNumbers(); break;
        case 5: _t->SelectFactorization(); break;
        case 6: _t->SelectPercentage(); break;
        case 7: _t->ReducedFormCheckSlot(); break;
        case 8: _t->QuestionMixedCheckSlot(); break;
        case 9: _t->AnswerMixedCheckSlot(); break;
        case 10: _t->AdditionCheckSlot(); break;
        case 11: _t->SubtractionCheckSlot(); break;
        case 12: _t->MultiplicationCheckSlot(); break;
        case 13: _t->DivisionCheckSlot(); break;
        case 14: _t->NrOfTermsBoxSlot(); break;
        case 15: _t->MaxMainDenominatorBoxSlot(); break;
        case 16: _t->newTask(); break;
        case 17: _t->slotPrefs(); break;
        case 18: _t->slotApplySettings(); break;
        case 19: _t->slotAboutToShowPage(); break;
        case 20: _t->goBack(); break;
        default: ;
        }
    }
}

const QMetaObject MainQtWidget::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_MainQtWidget.data,
      qt_meta_data_MainQtWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *MainQtWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainQtWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_MainQtWidget.stringdata0))
        return static_cast<void*>(const_cast< MainQtWidget*>(this));
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainQtWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
