/****************************************************************************
** Meta object code from reading C++ file 'ExerciseCompare.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kbruch-17.04.3/src/ExerciseCompare.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ExerciseCompare.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_ExerciseCompare_t {
    QByteArrayData data[5];
    char stringdata0[93];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ExerciseCompare_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ExerciseCompare_t qt_meta_stringdata_ExerciseCompare = {
    {
QT_MOC_LITERAL(0, 0, 15), // "ExerciseCompare"
QT_MOC_LITERAL(1, 16, 27), // "signalExerciseSolvedCorrect"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 21), // "signalExerciseSkipped"
QT_MOC_LITERAL(4, 67, 25) // "signalExerciseSolvedWrong"

    },
    "ExerciseCompare\0signalExerciseSolvedCorrect\0"
    "\0signalExerciseSkipped\0signalExerciseSolvedWrong"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ExerciseCompare[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,
       3,    0,   30,    2, 0x06 /* Public */,
       4,    0,   31,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ExerciseCompare::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ExerciseCompare *_t = static_cast<ExerciseCompare *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalExerciseSolvedCorrect(); break;
        case 1: _t->signalExerciseSkipped(); break;
        case 2: _t->signalExerciseSolvedWrong(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ExerciseCompare::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ExerciseCompare::signalExerciseSolvedCorrect)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ExerciseCompare::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ExerciseCompare::signalExerciseSkipped)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ExerciseCompare::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ExerciseCompare::signalExerciseSolvedWrong)) {
                *result = 2;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject ExerciseCompare::staticMetaObject = {
    { &ExerciseBase::staticMetaObject, qt_meta_stringdata_ExerciseCompare.data,
      qt_meta_data_ExerciseCompare,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ExerciseCompare::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ExerciseCompare::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ExerciseCompare.stringdata0))
        return static_cast<void*>(const_cast< ExerciseCompare*>(this));
    return ExerciseBase::qt_metacast(_clname);
}

int ExerciseCompare::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExerciseBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ExerciseCompare::signalExerciseSolvedCorrect()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void ExerciseCompare::signalExerciseSkipped()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void ExerciseCompare::signalExerciseSolvedWrong()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
